package com.tcctlo.law.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctlo.common.core.controller.BaseController;
import com.tcctlo.common.core.domain.AjaxResult;
import com.tcctlo.law.entity.CaseInformation;
import com.tcctlo.law.service.ICaseInformationService;
import com.tcctlo.law.vo.CaseArchivedVO;
import com.tcctlo.law.vo.CaseInformationEnterVO;
import com.tcctlo.law.vo.CaseInformationListVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * <p>
 * 案件信息表 前端控制器
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */

@RestController
@RequestMapping("/caseInformation")
public class CaseInformationController extends BaseController {

    @Autowired
    private ICaseInformationService iCaseInformationService;


    /**
     * 案件审核
     * @param params 参数：案件编号、审核状态、审核意见【id、auditStatus、auditOpinion】
     * @return
     */
    @PostMapping(value = "/caseReview")
    public AjaxResult caseReview(@RequestBody Map<String,Object> params) {
        return AjaxResult.success(iCaseInformationService.caseReview(params));
    }

    /**
     * 案件撤销
     * @param params 参数：案件编号、收案状态【id、caseStatus】
     * @return
     */
    @PostMapping(value = "/claimWithdrawal")
    public AjaxResult claimWithdrawal(@RequestBody Map<String,Object> params) {
        return AjaxResult.success(iCaseInformationService.claimWithdrawal(params));
    }

    /**
     * 设置案件结案
     * @param params 参数：案件编号、审核状态、审核意见【id、auditStatus、auditOpinion】
     * @return
     */
    @PostMapping(value = "/caseClosed")
    public AjaxResult caseClosed(@RequestBody Map<String,Object> params) {
        return AjaxResult.success(iCaseInformationService.caseClosed(params));
    }

    /**
     * 案件信息录入
     *
     * @param caseInfo 案件信息
     * @return 是否录入成功
     */
    @PostMapping(value = "/enterCaseInfo")
    public AjaxResult enterCaseInfo(@RequestBody CaseInformationEnterVO caseInfo) {
        Boolean result = iCaseInformationService.enterCaseInfo(caseInfo);
        if (result) {
            return AjaxResult.success("案件信息录入成功");
        } else {
            return AjaxResult.error("案件信息录入失败");
        }
    }

    @PostMapping(value = "/list")
    public AjaxResult list(@RequestParam(required = false) Integer current, @RequestParam(required = false) Integer size, @RequestBody(required = false) Map<String, Object> params) {
        if (current == null) {
            current = 1;
        }
        if (size == null) {
            size = 10;
        }
        Page<CaseInformationListVO> pageList = iCaseInformationService.list((Integer) params.get("current"), (Integer) params.get("size"), params);
        return AjaxResult.success(pageList);
    }

    /**
     * 案件查询【利冲信息库页面展示利冲信息对应的案件信息】
     * @param id 案件ID
     * @return 案件信息
     */
    @GetMapping(value = "/selectCaseById/{id}")
    public AjaxResult selectCaseById(@PathVariable("id") Long id) {
        CaseInformationListVO caseInformationListVO = iCaseInformationService.selectCaseById(id);
        return AjaxResult.success(caseInformationListVO);
    }

    /**
     * 根据案件ID查询案件详细信息
     *
     * @param id 案件ID
     * @return 结果集
     */
    @GetMapping(value = "/selectCaseInfoById/{id}")
    public AjaxResult selectCaseInfoById(@PathVariable("id") Long id) {
        CaseInformationEnterVO caseInformationEnterVO = iCaseInformationService.selectCaseInfoById(id);
        return AjaxResult.success(caseInformationEnterVO);
    }

    /**
     * 案件信息修改
     *
     * @param params 入参
     * @return 是否修改成功
     */
    @PostMapping(value = "/updateCaseInfo")
    public AjaxResult updateCaseInfo(@RequestBody CaseInformationEnterVO params) {
        Boolean res = iCaseInformationService.updateCaseInfo(params);
        if (res) {
            return AjaxResult.success("案件信息录入成功");
        } else {
            return AjaxResult.error("案件信息录入失败");
        }
    }

    /**
     * 案件归档【单个案件】
     *
     * @param caseArchivedVO 要归档的案件
     * @return 是否归档成功
     */
    @PostMapping(value = "/caseArchived")
    public AjaxResult caseArchived(@RequestBody CaseArchivedVO caseArchivedVO) {
        Boolean res = iCaseInformationService.caseArchived(caseArchivedVO);
        return AjaxResult.success(res);
    }


    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        CaseInformation caseInformation = iCaseInformationService.getById(id);
        return AjaxResult.success(caseInformation);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@RequestBody CaseInformation caseInformation) {
        Integer result = iCaseInformationService.create(caseInformation);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result = iCaseInformationService.delete(id);
        return AjaxResult.success(result);
    }

    /**
     * 案件删除【批量删除+单个删除】
     *
     * @param ids
     * @return
     */
    @GetMapping(value = "/deleteCase")
    public AjaxResult deleteCase(@RequestParam("ids") String ids) {
        return AjaxResult.success(iCaseInformationService.deleteCase(ids));
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@RequestBody CaseInformation params) {
        Integer result = iCaseInformationService.update(params);
        return AjaxResult.success(result);
    }
}
