package com.tcctlo.law.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctlo.common.core.domain.AjaxResult;
import com.tcctlo.law.entity.ImpulseInformation;
import com.tcctlo.law.service.IImpulseInformationService;
import com.tcctlo.law.vo.ImpulseInformationVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * <p>
 * 利冲信息表 前端控制器
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */

@RestController
@RequestMapping("/impulseInformation")
public class ImpulseInformationController {


    @Autowired
    private IImpulseInformationService iImpulseInformationService;

    @PostMapping(value = "/list")
    public AjaxResult list(@RequestBody Map<String, Object> params) {
        params.putIfAbsent("current", 1);
        params.putIfAbsent("size", 10);
        Page<ImpulseInformationVO> pageList = iImpulseInformationService.list(params);
        return AjaxResult.success(pageList);
    }


    /*@GetMapping(value = "/list")
    public AjaxResult list(@RequestParam(required = false) Integer current, @RequestParam(required = false) Integer size) {
        if (current == null) {
            current = 1;
        }
        if (size == null) {
            size = 10;
        }
        Page<ImpulseInformation> pageList = iImpulseInformationService.list(current, size);
        return AjaxResult.success(pageList);
    }*/
    /**
     * 模糊查询【用于搜索条件查询】
     *
     * @param caseName 【委托方】/【相对方】名称
     * @param isClient 是否是委托方
     * @return 结果集
     */
    @GetMapping(value = "/getAllByParam")
    public AjaxResult selectLikeByParam(@RequestParam("caseName") String caseName, @RequestParam("isClient") Integer isClient) {
        return AjaxResult.success(iImpulseInformationService.selectLikeByParam(caseName, isClient));
    }

    /**
     * 利冲检索
     * @param impulseInformation 利冲信息
     * @return 检索结果
     */
    @PostMapping("/retrievalConflict")
    public AjaxResult retrievalConflict(@RequestBody ImpulseInformation impulseInformation) {
        Boolean res = iImpulseInformationService.retrievalConflict(impulseInformation);
        return AjaxResult.success(res);
    }

    @GetMapping(value = "/{id}")
    public AjaxResult getById(@PathVariable("id") Long id) {
        ImpulseInformation impulseInformation = iImpulseInformationService.getById(id);
        return AjaxResult.success(impulseInformation);
    }

    @PostMapping(value = "/create")
    public AjaxResult create(@RequestBody ImpulseInformation params) {
        Integer result = iImpulseInformationService.create(params);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/delete/{id}")
    public AjaxResult delete(@PathVariable("id") Long id) {
        Integer result = iImpulseInformationService.delete(id);
        return AjaxResult.success(result);
    }

    @PostMapping(value = "/update")
    public AjaxResult update(@RequestBody ImpulseInformation params) {
        Integer result = iImpulseInformationService.update(params);
        return AjaxResult.success(result);
    }


}
