package com.tcctlo.law.mapper;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctlo.law.entity.CaseInformation;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.tcctlo.law.vo.CaseInformationListVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 案件信息表 Mapper 接口
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */
public interface CaseInformationMapper extends BaseMapper<CaseInformation> {

    /**
     * 分页条件查询
     * @param page 分页对象
     * @param condition 条件参数
     * @return 结果集
     */
    Page<CaseInformationListVO> selectCondition(@Param("page") Page<CaseInformationListVO> page, @Param("condition") Map<String, Object> condition);


    /**
     * 根据案件ID查询案件信息
     * @param id 案件ID
     * @return 结果集
     */
    CaseInformationListVO selectCaseById(@Param("id") Long id);


    /**
     * 案件归档
     * @param caseId 要归档的案件ID
     * @return 受影响记录数
     */
    int caseArchived(@Param("caseId") Long caseId);

    /**
     * 批量逻辑删除案件信息
     * @param longList 案件ID集合
     */
    int removeByIds(@Param("ids") List<Long> longList);

    /**
     * 判断案件是否有相关文件
     * @param id 案件id
     * @return 结果集
     */
    int selectCaseFileNum(@Param("id") Long id);

    /**
     * 根据案件ID查询案件信息
     * @param id 案件ID
     * @return 结果集
     */
    CaseInformation selectCaseInfoById(@Param("id") Long id);

    /**
     * 案件审核
     * @param params 参数
     * @return 是否审核成功
     */
    boolean caseReview(@Param("params") Map<String, Object> params);

    /**
     * 案件撤销
     * @param params 参数
     * @return 是否撤销成功
     */
    Boolean claimWithdrawal(@Param("params") Map<String, Object> params);

    /**
     * 案件结案
     * @param params 参数
     * @return 结案结果
     */
    Boolean caseClosed(@Param("params") Map<String, Object> params);
}
