package com.tcctlo.law.mapper;

import com.tcctlo.law.entity.CaseLawyer;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.tcctlo.law.entity.ImpulseInformation;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * <p>
 * 案件律师表 Mapper 接口
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */
public interface CaseLawyerMapper extends BaseMapper<CaseLawyer> {

    /**
     * 批量插入
     * @param list 数据集
     * @return 受影响行数
     */
    int insertBatch(List<CaseLawyer> list);


    /**
     * 根据案件ID查询代理律师
     * @param caseId 案件ID
     * @return 结果集
     */
    CaseLawyer selectAttorneyAgentLawByCaseId(@Param("caseId") Long caseId);

    /**
     * 根据案件ID查询协办律师
     * @param caseId 案件ID
     * @return 结果集
     */
    List<CaseLawyer> selectAssistingLawyerByCaseId(@Param("caseId") Long caseId);

    /**
     * 根据案件ID查询所有现任律师
     * @param caseId 案件ID
     * @return 结果集
     */
    List<CaseLawyer> selectAllPrimeLawyerByCaseId(@Param("caseId") Long caseId);

    /**
     * 根据案件律师表的id集合修改律师状态为【原承办律师】
     * @param ids id集合
     * @return 受影响行数
     */
    int updateByIds(@Param("ids") List<Long> ids);

    /**
     * 根据案件ID逻辑删除案件相关律师信息
     * @param caseId 案件ID
     * @return 受影响行数
     */
    int deleteLawyerByCaseId(@Param("caseIds") List<Long> caseId);
}
