package com.tcctlo.law.mapper;

import com.tcctlo.law.entity.CaseLawyer;
import com.tcctlo.law.entity.FileManager;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * <p>
 * 文件管理 Mapper 接口
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */

public interface FileManagerMapper extends BaseMapper<FileManager> {

    /**
     * 批量插入
     * @param list 数据集
     * @return 受影响行数
     */
    int insertBatch(List<FileManager> list);

    /**
     * 根据案件ID和收款记录表中存储的文件ID查询文件管理信息
     * @param caseId 案件ID
     * @param fileId 收款记录表中存储的文件ID
     * @return 结果集
     */
    FileManager selectByCaseIdAndFileId(@Param("caseId") Long caseId, @Param("fileId") Long fileId);

    /**
     * 根据案件ID批量删除文件管理信息
     * @param caseIds 案件ID集合
     * @return
     */
    int removeByCaseId(@Param("caseIds") List<Long> caseIds);

    /**
     * 根据案件ID和收款记录表中存储的文件ID批量删除文件管理信息
     * @param caseId 案件ID
     * @param fileIds 收款记录表中存储的文件ID
     */
    int removeByCaseIdAndFileIds(@Param("caseId") Long caseId, @Param("fileIds") List<Long> fileIds);

    /**
     * 查询案件相关的所有文件
     * @param caseId 案件ID
     * @return 结果集
     */
    List<FileManager> selectFileByCaseId(@Param("caseId") Long caseId);
}
