package com.tcctlo.law.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctlo.law.entity.ImpulseInformation;
import com.tcctlo.law.vo.CaseInformationListVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 利冲信息表 Mapper 接口
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */
public interface ImpulseInformationMapper extends BaseMapper<ImpulseInformation> {

    /**
     * 批量插入
     * @param list 数据集
     * @return 受影响行数
     */
    int insertBatch(List<ImpulseInformation> list);

    /**
     * 批量软删除
     * @param list 参数
     * @return 结果集
     */
    int deleteBatchLogic(List<ImpulseInformation> list);


    /**
     * 根据案件id查询
     * @param caseId 案件ID
     * @param clientFlag 是否委托方标志
     * @return 结果集
     */
    List<ImpulseInformation> selectByCaseId(@Param("caseId") Long caseId, @Param("clientFlag") Integer clientFlag);

    /**
     * 查询修改后的【委托方】+【相对方】信息
     * @param caseId 案件ID
     * @return 结果集
     */
    List<ImpulseInformation> selectByCaseIdAdnDelFlag(@Param("caseId") Long caseId);

    /**
     * 利冲检索
     * @param impulseInformation 检索数据
     * @return 结果集
     */
    List<ImpulseInformation> retrievalConflict(@Param("info") ImpulseInformation impulseInformation);

    /**
     * 根据案件ID批量删除
     * @param caseId 案件ID集合
     * @return 结果集
     */
    int removeByCaseId(@Param("caseId") List<Long> caseId);


    /**
     * 分页条件查询
     * @param page 分页
     * @param condition 条件
     * @return 结果集
     */
    Page<ImpulseInformation> selectCondition(@Param("page") Page<ImpulseInformation> page, @Param("condition") Map<String, Object> condition);
}
