package com.tcctlo.law.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.tcctlo.law.entity.CaseInformation;
import com.tcctlo.law.vo.CaseArchivedVO;
import com.tcctlo.law.vo.CaseInformationEnterVO;
import com.tcctlo.law.vo.CaseInformationListVO;

import java.util.Map;

/**
 * <p>
 * 案件信息表 服务类
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */
public interface ICaseInformationService extends IService<CaseInformation>{

    /**
     * <p>
     * 分页列表查询
     * </p>
     *
     * @param pageNo 页码
     * @param pageSize 每页大小
     * @param params 查询条件
     * @return 结果集
     */
    Page<CaseInformationListVO> list(Integer pageNo, Integer pageSize, Map<String, Object> params);

    /**
     * <p>
     * 详情接口
     * </p>
     *
     * @param id
     * @return
     */
    CaseInformation getById(Long id);

    /**
     * 根据案件ID查询案件信息
     * @param id 案件id
     * @return 结果集
     */
    CaseInformationListVO selectCaseById(Long id);

    /**
     * <p>
     * 新增接口
     * </p>
     *
     * @param caseInformation
     * @return
     */
    Integer create(CaseInformation caseInformation);


    /**
     * <p>
     * 删除接口
     * </p>
     *
     * @param id
     * @return
     */
    Integer delete(Long id);

    /**
     * <p>
     * 更新接口
     * </p>
     *
     * @param caseInformation
     * @return
     */
    Integer update(CaseInformation caseInformation);

    /**
     * 案件信息录入
     *
     * @param caseInfo 案件信息
     * @return 是否录入成功
     */
    Boolean enterCaseInfo(CaseInformationEnterVO caseInfo);

    /**
     * 根据案件ID查询案件详细信息
     * @param id 案件ID
     * @return 结果集
     */
    CaseInformationEnterVO selectCaseInfoById(Long id);

    /**
     * 案件信息修改
     * @param params 案件信息
     * @return 受影响行数
     */
    Boolean updateCaseInfo(CaseInformationEnterVO params);

    /**
     * 删除案件信息
     * @param ids 案件id集合
     * @return 结果集
     */
    Boolean deleteCase(String ids);

    /**
     * 案件归档
     * @param caseArchivedVO 归档案件+归档文件
     * @return 是否归档成功
     */
    Boolean caseArchived(CaseArchivedVO caseArchivedVO);

    /**
     * 案件审核
     * @param params 参数
     * @return 是否审核成功
     */
    Boolean caseReview(Map<String, Object> params);

    /**
     * 案件撤销
     * @param params 参数
     * @return 是否撤销成功
     */
    Boolean claimWithdrawal(Map<String, Object> params);

    /**
     * 案件结案
     * @param params 参数
     * @return 是否结案成功
     */
    Boolean caseClosed(Map<String, Object> params);
}
