package com.tcctlo.law.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.deepoove.poi.XWPFTemplate;
import com.tcctlo.common.core.domain.AjaxResult;
import com.tcctlo.law.entity.ContractTemplate;
import com.tcctlo.law.mapper.ContractTemplateMapper;
import com.tcctlo.law.service.IContractTemplateService;
import com.tcctlo.law.tools.FileUpload;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;
import java.time.LocalDateTime;
import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 合同模板 服务实现类
 * </p>
 *
 * @author
 * @since 2025-02-18
 */
@Service
public class ContractTemplateServiceImpl extends ServiceImpl<ContractTemplateMapper, ContractTemplate> implements IContractTemplateService {


    @Resource
    private ContractTemplateMapper contractTemplateMapper;

    @Resource
    private FileUpload fileUpload;

    @Value("${serviceFilePath}")
    private String serviceFilePath;

    @Value("${generatedWordPath}")
    private String generatedWordPath;

    /*@Override
    public Page<ContractTemplate> list(Integer pageNo, Integer pageSize) {
        return contractTemplateMapper.selectPage(new Page<>(pageNo, pageSize), new QueryWrapper<>());
    }*/


    @Override
    public Page<ContractTemplate> list(Map<String, Object> params) {
        return contractTemplateMapper.selectPage(new Page<>((Integer) params.get("current"), (Integer) params.get("size")), new QueryWrapper<>());
    }

    @Override
    public ContractTemplate getById(Long id) {
        ContractTemplate contractTemplate = contractTemplateMapper.selectById(id);
        return contractTemplate;
    }

    /**
     * 下载文件至本地
     *
     * @param response 响应
     */
    @GetMapping("/downloadFileOnLocal")
    public AjaxResult downloadFile(HttpServletResponse response, @RequestParam("urlPath") String urlPath, @RequestParam("path") String path) {
        try {
            URL url = new URL(urlPath);
            String filePath = "F:\\fileDownload\\" + UUID.randomUUID() + urlPath.substring(urlPath.lastIndexOf("."));
            URLConnection conn = url.openConnection();
            InputStream inputStream = conn.getInputStream();
            FileOutputStream fileOutputStream = new FileOutputStream(filePath);
            int bytesum = 0;
            int byteread;
            byte[] buffer = new byte[1024];
            while ((byteread = inputStream.read(buffer)) != -1) {
                bytesum += byteread;
                fileOutputStream.write(buffer, 0, byteread);
            }
            fileOutputStream.close();
            return AjaxResult.success("下载成功");
        } catch (Exception e) {
            throw new RuntimeException("下载失败");
        }
    }

    @Override
    public Integer create(ContractTemplate contractTemplate) {
        try {
            URL url = new URL(contractTemplate.getFileUrl());
            String filePath = serviceFilePath + UUID.randomUUID() + contractTemplate.getFileUrl().substring(contractTemplate.getFileUrl().lastIndexOf("."));
//            String filePath = "/backitems/lawFirm/wordTemplate/" + UUID.randomUUID() + contractTemplate.getFileUrl().substring(contractTemplate.getFileUrl().lastIndexOf("."));
            contractTemplate.setFilePath(filePath);
            URLConnection conn = url.openConnection();
            InputStream inputStream = conn.getInputStream();
            FileOutputStream fileOutputStream = new FileOutputStream(filePath);
            int bytesum = 0;
            int byteread;
            byte[] buffer = new byte[1024];
            while ((byteread = inputStream.read(buffer)) != -1) {
                bytesum += byteread;
                fileOutputStream.write(buffer, 0, byteread);
            }
            fileOutputStream.close();
        } catch (Exception e) {
            throw new RuntimeException("存储至服务器失败");
        }

        return contractTemplateMapper.insert(contractTemplate);
    }

    @Override
    public Integer delete(Long id) {
        return contractTemplateMapper.deleteById(id);
    }

    @Override
    public Integer update(ContractTemplate contractTemplate) {
        return contractTemplateMapper.updateById(contractTemplate);
    }

    @Override
    public Integer deleteTemplate(Map<String, String> param) {
        List<Long> ids = Arrays.stream(param.get("ids").split(","))
                .mapToLong(Long::parseLong)
                .boxed()
                .collect(Collectors.toList());
        return contractTemplateMapper.deleteTemplate(ids);
    }

    @Override
    public void getWord(Long id) throws Exception {
        ContractTemplate contractTemplate = contractTemplateMapper.selectById(id);
        String filePath = contractTemplate.getFilePath();
        HashMap<String, String> map = new HashMap<>();
        map.put("firstParty","甲方名称");
        map.put("secondParty","乙方名称");
        map.put("solicitor","张三、李四、王五");
        map.put("commitment","委托事项委托事项委托事项委托事项");
        map.put("signDate", LocalDateTime.now().toString());
        map.put("legalRepresentative","法定代表人");
        map.put("idNo","620121199708060011");
        map.put("creditCode","52031001156477894");
        map.put("bankName","中国建设银行");
        map.put("accountNum","4561112557894411");
        map.put("address","云南省昆明市");
        map.put("phone","13359490766");
        map.put("facsimile","0931-6554211");
        map.put("postcode","730300");
        XWPFTemplate template = XWPFTemplate.compile(filePath).render(map);
        String savePath = generatedWordPath + UUID.randomUUID().toString() + ".docx";
        FileOutputStream out = new FileOutputStream(savePath);
        template.write(out);
        out.flush();
        out.close();
        template.close();
        File file = new File(savePath);
        System.out.println(fileUpload.uploadFile(file));
    }

}
