package com.tcctlo.law.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.date.DateUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.tcctlo.common.utils.StringUtils;
import com.tcctlo.law.entity.CaseInformation;
import com.tcctlo.law.entity.ImpulseInformation;
import com.baomidou.mybatisplus.extension.service.IService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tcctlo.law.mapper.CaseInformationMapper;
import com.tcctlo.law.mapper.ImpulseInformationMapper;
import com.tcctlo.law.service.IImpulseInformationService;
import com.tcctlo.law.vo.ImpulseInformationVO;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.Map;
import java.util.function.Consumer;
import java.util.stream.Collectors;

/**
 * <p>
 * 利冲信息表 服务实现类
 * </p>
 *
 * @author 张世琪
 * @since 2025-02-06
 */
@Service
public class ImpulseInformationServiceImpl extends ServiceImpl<ImpulseInformationMapper, ImpulseInformation> implements IImpulseInformationService {


    @Resource
    private ImpulseInformationMapper impulseInformationMapper;

    @Resource
    private CaseInformationMapper caseInformationMapper;

    @Override
    public Page<ImpulseInformationVO> list(Map<String, Object> params) {
        Page<ImpulseInformationVO> resPage = new Page<>();
        Page<ImpulseInformation> page = impulseInformationMapper.selectCondition(new Page<>((Integer) params.get("current"), (Integer) params.get("size")), params);
        if (page.getRecords() != null){
            List<ImpulseInformationVO> list = BeanUtil.copyToList(page.getRecords(), ImpulseInformationVO.class);
            list.stream().peek(item -> {
                if (item.getCaseId() != null){
                    CaseInformation caseInformation = caseInformationMapper.selectById(item.getCaseId());
                    item.setCaseInfoName(caseInformation.getCaseName());
                    item.setTermOfConsultancy(caseInformation.getTermOfConsultancy());
                    item.setArchiveStatus(caseInformation.getArchiveStatus());
                    item.setIsFinishCase(caseInformation.getIsFinishCase());
                }
            }).collect(Collectors.toList());
            resPage.setRecords(list);
            resPage.setTotal(page.getTotal());
            resPage.setSize(page.getSize());
            resPage.setCurrent(page.getCurrent());
        }
        return resPage;
    }

    /*@Override
    public Page<ImpulseInformation> list(Map<String, Object> params) {
        return impulseInformationMapper.selectPage(new Page<>((Integer) params.get("current"), (Integer) params.get("size")), new QueryWrapper<>());
    }*/

    @Override
    public List<ImpulseInformation> selectLikeByParam(String caseName, Integer isClient) {
        LambdaQueryWrapper<ImpulseInformation> wrapper = new LambdaQueryWrapper<>();
        wrapper.like(StringUtils.isNotNull(caseName), ImpulseInformation::getCaseName, caseName)
                .eq(StringUtils.isNotNull(isClient), ImpulseInformation::getIsClient, isClient)
                .eq(ImpulseInformation::getDelFlag, 0)
                .eq(ImpulseInformation::getStatus, 0)
                .orderByDesc(ImpulseInformation::getCreateTime);
        return impulseInformationMapper.selectList(wrapper);
    }

    @Override
    public Boolean retrievalConflict(ImpulseInformation impulseInformation) {
        /**
         * 当 impulseInformation.getIsClient() 的值为 0 时，1 - 0 结果为 1；当 impulseInformation.getIsClient() 的值为 1 时，1 - 1 结果为 0
         * 注意：
         * 1、如果是【委托方】就去检索【相对方】中有没有
         * 2、如果是【相对方】就去检索【委托方】中有没有
         * 3、【委托方】不能是律所中任何一个案件的被告方====【被告方】不能是律所中任何一个案件的【委托方】
         */
        impulseInformation.setIsClient(1 - impulseInformation.getIsClient());
        List<ImpulseInformation> resList = impulseInformationMapper.retrievalConflict(impulseInformation);
        return resList.isEmpty();
    }

    @Override
    public ImpulseInformation getById(Long id) {
        return impulseInformationMapper.selectById(id);
    }

    @Override
    public Integer create(ImpulseInformation impulseInformation) {
        return impulseInformationMapper.insert(impulseInformation);
    }

    @Override
    public Integer delete(Long id) {
        return impulseInformationMapper.deleteById(id);
    }

    @Override
    public Integer update(ImpulseInformation impulseInformation) {
        return impulseInformationMapper.updateById(impulseInformation);
    }


}
